Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1673)

Unified Diff: services/data_decoder/public/cpp/decode_image.h

Issue 2774463002: image_decoder service -> data_decoder service (Closed)
Patch Set: . Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « services/data_decoder/public/cpp/BUILD.gn ('k') | services/data_decoder/public/cpp/decode_image.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: services/data_decoder/public/cpp/decode_image.h
diff --git a/services/image_decoder/public/cpp/decode.h b/services/data_decoder/public/cpp/decode_image.h
similarity index 53%
rename from services/image_decoder/public/cpp/decode.h
rename to services/data_decoder/public/cpp/decode_image.h
index ea0fa2e848ff7f23132746dc1afc13cbe195349f..2517fdc5d5f087c9c6f72beebec6768967cdf6f9 100644
--- a/services/image_decoder/public/cpp/decode.h
+++ b/services/data_decoder/public/cpp/decode_image.h
@@ -2,14 +2,14 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef SERVICES_IMAGE_DECODER_PUBLIC_CPP_DECODE_H_
-#define SERVICES_IMAGE_DECODER_PUBLIC_CPP_DECODE_H_
+#ifndef SERVICES_DATA_DECODER_PUBLIC_CPP_DECODE_H_
+#define SERVICES_DATA_DECODER_PUBLIC_CPP_DECODE_H_
#include <stdint.h>
#include <vector>
-#include "services/image_decoder/public/interfaces/image_decoder.mojom.h"
+#include "services/data_decoder/public/interfaces/image_decoder.mojom.h"
namespace gfx {
class Size;
@@ -19,11 +19,11 @@ namespace service_manager {
class Connector;
}
-namespace image_decoder {
+namespace data_decoder {
const uint64_t kDefaultMaxSizeInBytes = 128 * 1024 * 1024;
// Helper function to decode an image via the image_decoder service. For images
// with multiple frames (e.g. ico files), a frame with a size as close as
// possible to |desired_image_frame_size| is chosen (tries to take one in larger
// size if there's no precise match). Passing gfx::Size() as
@@ -32,14 +32,14 @@ const uint64_t kDefaultMaxSizeInBytes = 128 * 1024 * 1024;
// Upon completion, |callback| is invoked on the calling thread TaskRunner with
// an SkBitmap argument. The SkBitmap will be null on failure and non-null on
// success.
-void Decode(service_manager::Connector* connector,
- const std::vector<uint8_t>& encoded_bytes,
- mojom::ImageCodec codec,
- bool shrink_to_fit,
- uint64_t max_size_in_bytes,
- const gfx::Size& desired_image_frame_size,
- const mojom::ImageDecoder::DecodeImageCallback& callback);
+void DecodeImage(service_manager::Connector* connector,
+ const std::vector<uint8_t>& encoded_bytes,
+ mojom::ImageCodec codec,
+ bool shrink_to_fit,
+ uint64_t max_size_in_bytes,
+ const gfx::Size& desired_image_frame_size,
+ const mojom::ImageDecoder::DecodeImageCallback& callback);
-} // namespace image_decoder
+} // namespace data_decoder
-#endif // SERVICES_IMAGE_DECODER_PUBLIC_CPP_DECODE_H_
+#endif // SERVICES_DATA_DECODER_PUBLIC_CPP_DECODE_H_
« no previous file with comments | « services/data_decoder/public/cpp/BUILD.gn ('k') | services/data_decoder/public/cpp/decode_image.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -19,11 +19,11 @@ namespace service_manager {
const uint64_t kDefaultMaxSizeInBytes = 128 * 1024 * 1024;
-// Helper function to decode an image via the image_decoder service. For images
+// Helper function to decode an image via the data_decoder service. For images
// with multiple frames (e.g. ico files), a frame with a size as close as
// possible to |desired_image_frame_size| is chosen (tries to take one in larger
This is Rietveld 408576698